package activity

type Activities struct {
	AddGatewayV1       []AddGatewayV1
	AssertLocationV1   []AssertLocationV1
	AssertLocationV2   []AssertLocationV2
	PaymentV1          []PaymentV1
	PaymentV2          []PaymentV2
	RewardsV1          []RewardsV1
	RewardsV2          []RewardsV2
	StakeValidatorV1   []StakeValidatorV1
	TokenBurnV1        []TokenBurnV1
	TransferHotspotV1  []TransferHotspotV1
	UnstakeValidatorV1 []UnstakeValidatorV1
}

type AddGatewayV1 struct {
	Hash       string `json:"hash"`
	Fee        int    `json:"fee"`
	Owner      string `json:"owner"`
	Payer      string `json:"payer"`
	Gateway    string `json:"gateway"`
	StakingFee int    `json:"staking_fee"`
}

type AssertLocationV1 struct {
	Hash       string `json:"hash"`
	Fee        int    `json:"fee"`
	Nonce      int    `json:"nonce"`
	Owner      string `json:"owner"`
	Payer      string `json:"payer,omitempty"`
	Gateway    string `json:"gateway"`
	Location   string `json:"location"`
	StakingFee int    `json:"staking_fee"`
}

type AssertLocationV2 struct {
	Hash       string `json:"hash"`
	Fee        int    `json:"fee"`
	Gain       int    `json:"gain"`
	Nonce      int    `json:"nonce"`
	Owner      string `json:"owner"`
	Payer      string `json:"payer,omitempty"`
	Gateway    string `json:"gateway"`
	Location   string `json:"location"`
	Elevation  int    `json:"elevation"`
	StakingFee int    `json:"staking_fee"`
}

type PaymentV1 struct {
	Hash   string `json:"hash"`
	Amount int    `json:"amount"`
	Fee    int    `json:"fee"`
	Nonce  int    `json:"nonce"`
	Payer  string `json:"payer"`
	Payee  string `json:"payee"`
}

type PaymentV2 struct {
	Hash     string `json:"hash"`
	Fee      int    `json:"fee"`
	Nonce    int    `json:"nonce"`
	Payer    string `json:"payer"`
	Payments []struct {
		Amount int    `json:"amount"`
		Memo   string `json:"memo"`
		Payee  string `json:"payee"`
	}
}

type reward struct {
	Account string `json:"account,omitempty"`
	Amount  int    `json:"amount"`
	Gateway string `json:"gateway,omitempty"`
	Type    string `json:"type"`
}

type RewardsV1 struct {
	Hash       string   `json:"hash"`
	StartEpoch int      `json:"start_epoch"`
	EndEpoch   int      `json:"end_epoch"`
	Rewards    []reward `json:"rewards"`
}

type RewardsV2 struct {
	Hash       string   `json:"hash"`
	StartEpoch int      `json:"start_epoch"`
	EndEpoch   int      `json:"end_epoch"`
	Rewards    []reward `json:"rewards"`
}

type StakeValidatorV1 struct {
	Address        string `json:"address"`
	Fee            int    `json:"fee"`
	Hash           string `json:"hash"`
	Owner          string `json:"owner"`
	Stake          int    `json:"stake"`
	OwnerSignature string `json:"owner_signature"`
}

type TokenBurnV1 struct {
	Fee    int    `json:"fee"`
	Hash   string `json:"hash"`
	Memo   string `json:"memo"`
	Nonce  int    `json:"nonce"`
	Payer  string `json:"payer"`
	Payee  string `json:"payee"`
	Amount int    `json:"amount"`
}

type TransferHotspotV1 struct {
	Hash           string `json:"hash"`
	Fee            int    `json:"fee"`
	Buyer          string `json:"buyer"`
	Seller         string `json:"seller"`
	Gateway        string `json:"gateway"`
	BuyerNonce     int    `json:"buyer_nonce"`
	AmountToSeller int    `json:"amount_to_seller"`
}

type UnstakeValidatorV1 struct {
	Address            string `json:"address"`
	Owner              string `json:"owner"`
	OwnerSignature     string `json:"owner_signature"`
	Fee                int    `json:"fee"`
	StakeAmount        int    `json:"stake_amount"`
	StakeReleaseHeight int    `json:"stake_release_height"`
	Hash               string `json:"hash"`
}
